@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package SVG::Estimate;
-$SVG::Estimate::VERSION = '1.0102';
+$SVG::Estimate::VERSION = '1.0103';
 use XML::Hash::LX;
 use XML::LibXML;
 use File::Slurp;
@@ -24,7 +24,7 @@ SVG::Estimate - Estimates the length of all the vectors in an SVG file.
 
 =head1 VERSION
 
-version 1.0102
+version 1.0103
 
 =head1 SYNOPSIS
 
@@ -288,6 +288,10 @@ sub sum {
                 ##Handle transforms on an element
                 if (exists $params{transform}) {
                     $self->push_transform($params{transform});
+                    if ($self->summarize) {
+                        print "transform stack: ". join(' ', @{ $self->transform_stack });
+                        print "\n";
+                    }
                 }
                 $params{transformer} = $self->transformer;
                 my $shape = $class->new(%params);
@@ -311,6 +315,10 @@ sub sum {
                 if (exists $element->{'-transform'}) {
                     $self->push_transform($element->{'-transform'});
                     $has_transform = 1;
+                    if ($self->summarize) {
+                        print "transform stack: ". join(' ', @{ $self->transform_stack });
+                        print "\n";
+                    }
                 }
             }
         }
